remove test_support.TestSkipped and just use unittest.SkipTest
diff --git a/Lib/test/test_posix.py b/Lib/test/test_posix.py
index 5f40060..864f963 100644
--- a/Lib/test/test_posix.py
+++ b/Lib/test/test_posix.py
@@ -5,7 +5,7 @@
 try:
     import posix
 except ImportError:
-    raise test_support.TestSkipped, "posix is not available"
+    raise unittest.SkipTest, "posix is not available"
 
 import time
 import os
@@ -242,10 +242,10 @@
                 os.mkdir(base_path)
                 os.chdir(base_path)
             except:
 #               Just returning nothing instead of the TestSkipped exception,
 #               because the test results in Error in that case.
 #               Is that ok?
 #                raise test_support.TestSkipped, "cannot create directory for testing"
                 return
 
             try:
@@ -253,7 +253,7 @@
                     try:
                         os.mkdir(dirname)
                     except:
-                        raise test_support.TestSkipped, "mkdir cannot create directory sufficiently deep for getcwd test"
+                        raise unittest.SkipTest, "mkdir cannot create directory sufficiently deep for getcwd test"
 
                     os.chdir(dirname)
                     try:
@@ -242,10 +242,10 @@
                 os.chdir(base_path)
             except:
-#               Just returning nothing instead of the TestSkipped exception,
+#               Just returning nothing instead of the SkipTest exception,
 #               because the test results in Error in that case.
 #               Is that ok?
@@ -242,10 +242,10 @@
 #               because the test results in Error in that case.
 #               Is that ok?
-#                raise test_support.TestSkipped, "cannot create directory for testing"
+#                raise unittest.SkipTest, "cannot create directory for testing"
                 return
 